@@ -41,10 +41,14 @@ class CoverSourceQuality(enum.IntFlag):
     # whether or not the search query matching is fuzzy (does a typo return results ?)
     FUZZY_SEARCH = 0
     EXACT_SEARCH = 1 << 1
+    # whether or not the source can return cover images for the correct album, but not being the front cover
+    # unused for now
+    NOT_FRONT_COVER_RESULT_RISK = 0
+    NO_NOT_FRONT_COVER_RESULT_RISK = 1 << 2
     # whether or not the source will return complete crap instead of no results when it has not found a real match
-    # this seems similar to the previous flags but is different
+    # this seems similar to the fuzzy flags but is different
     UNRELATED_RESULT_RISK = 0
-    NO_UNRELATED_RESULT_RISK = 1 << 2
+    NO_UNRELATED_RESULT_RISK = 1 << 3
 
     def isReference(self) -> bool:
         """
@@ -68,6 +72,7 @@ class CoverImageMetadata(enum.IntFlag):
 
 HAS_JPEGOPTIM = shutil.which("jpegoptim") is not None
 HAS_OPTIPNG = shutil.which("optipng") is not None
+HAS_OXIPNG = shutil.which("oxipng") is not None
 SUPPORTED_IMG_FORMATS = {"jpg": CoverImageFormat.JPEG, "jpeg": CoverImageFormat.JPEG, "png": CoverImageFormat.PNG}
 FORMAT_EXTENSIONS = {CoverImageFormat.JPEG: "jpg", CoverImageFormat.PNG: "png"}
 
@@ -510,7 +515,7 @@ class CoverSourceResult:
     @staticmethod
     async def crunch(image_data, format, silent=False):
         """Crunch image data, and return the processed data, or orignal data if operation failed."""
-        if ((format is CoverImageFormat.PNG) and (not HAS_OPTIPNG)) or (
+        if ((format is CoverImageFormat.PNG) and (not (HAS_OPTIPNG or HAS_OXIPNG))) or (
             (format is CoverImageFormat.JPEG) and (not HAS_JPEGOPTIM)
         ):
             return image_data
@@ -521,7 +526,10 @@ class CoverSourceResult:
                 tmp_out_file.write(image_data)
             size_before = len(image_data)
             if format is CoverImageFormat.PNG:
-                cmd = ["optipng", "-quiet", "-o1"]
+                if HAS_OXIPNG:
+                    cmd = ["oxipng", "-q", "-s"]
+                else:
+                    cmd = ["optipng", "-quiet", "-o1"]
             elif format is CoverImageFormat.JPEG:
                 cmd = ["jpegoptim", "-q", "--strip-all"]
             cmd.append(tmp_out_filepath)
